@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2001 Dug Song <dugsong@monkey.org>
  *
- * $Id: dnet.h,v 1.4 2002/04/05 03:05:40 dugsong Exp $
+ * $Id$
  */
 
 #ifndef DNET_H
@@ -13,15 +13,19 @@
 
 #include <dnet/eth.h>
 #include <dnet/ip.h>
+#include <dnet/ip6.h>
 #include <dnet/addr.h>
 #include <dnet/arp.h>
+#include <dnet/ndisc.h>
 #include <dnet/icmp.h>
 #include <dnet/tcp.h>
 #include <dnet/udp.h>
+#include <dnet/sctp.h>
 
 #include <dnet/intf.h>
 #include <dnet/route.h>
 #include <dnet/fw.h>
+#include <dnet/tun.h>
 
 #include <dnet/blob.h>
 #include <dnet/rand.h>
